<?php

// Block direct access to the main plugin file.
defined('ABSPATH') or die('No script kiddies please!');


class Elementor_Grid_Posts5 extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'gridposts5';
    }

    public function get_title()
    {
        return __('Grid Posts 5', 'ahura');
    }

    public function get_icon()
    {
        return 'fa fa-th-large';
    }

    public function get_categories()
    {
        return ['ahuraelements'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'ahura'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $categories = get_categories();
        $cats       = array();
        foreach ($categories as $category) {
            $cats[$category->term_id] = $category->name;
        }
        $default = key($cats);
        $this->add_control(
            'catsid',
            [
                'label'    => __('Categories', 'ahura'),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'options'  => $cats,
                'label_block' => true,
                'multiple' => true,
                'default' => $default
            ]
        );


        $this->add_control(
            'post_order',
            [
                'label' => __('Sort', 'ahura'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'DESC',
                'options' => [
                    'ASC' => [
                        'title' => __('Ascending', 'ahura'),
                        'icon' => 'fa fa-arrow-up'
                    ],
                    'DESC' => [
                        'title' => __('Descending', 'ahura'),
                        'icon' => 'fa fa-arrow-down'
                    ],
                ],
                'toggle' => true
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $catidd   = $settings['catsid'];
        $post_order = $settings['post_order'];
        $postbox1 = new WP_Query(array(
            'posts_per_page' => 1,
            'cat'            => $catidd,
            'order'         =>  $post_order
        ));
        $postbox2 = new WP_Query(array(
            'posts_per_page' => 1,
            'cat'            => $catidd,
            'order'         =>  $post_order,
            'offset'         => 1
        ));
        $postbox3 = new WP_Query(array(
            'posts_per_page' => 1,
            'cat'            => $catidd,
            'order'         =>  $post_order,
            'offset'         => 2
        ));
        if ($postbox1->have_posts()) : ?>
        <?php while ($postbox1->have_posts()) : $postbox1->the_post(); ?>
            <div class="grid-post-5">
                <a href="<?php the_permalink();?>" class="grid-post-5-right" style="background-image:url(<?php echo get_the_post_thumbnail_url()?>);">
                    <h2><?php the_title()?></h2>
        </a>
                <?php endwhile;?>
                <div class="grid-post-5-left">
                <?php while ($postbox2->have_posts()) : $postbox2->the_post(); ?>
                    <div class="grid-post-5-left-top" style="background-image:url(<?php echo get_the_post_thumbnail_url()?>);">
                    <h2><?php the_title()?></h2>
                    </div>
                    <?php endwhile;?>
                    <?php while ($postbox3->have_posts()) : $postbox3->the_post(); ?>
                    <div class="grid-post-5-left-bottom" style="background-image:url(<?php echo get_the_post_thumbnail_url()?>);">
                    <h2><?php the_title()?></h2>
                    </div>
                    <?php endwhile;?>
                </div>
            </div>
            <?php wp_reset_postdata(); ?>
            <?php else:?>
					<div class="mw_element_error">
						<?php echo __('Nothing found. Edit the page with Mentor and select a category for this section.','ahura');?>
					</div>
        <?php endif; ?>
<?php
    }
}
