<?php

// Block direct access to the main plugin file.
defined('ABSPATH') or die('No script kiddies please!');


class Elementor_Introduction_Box extends \Elementor\Widget_Base
{
    public function get_name()
    {
        return 'introductionbox';
    }
  
    public function get_title()
    {
        return __('Introduction Box', 'ahura');
    }

    public function get_icon()
    {
        return 'fa fa-file';
    }

    public function get_categories()
    {
        return [ 'ahuraelements' ];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'ahura'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __('Title', 'ahura'),
                'type' => \Elementor\Controls_Manager::TEXT,
                "default" => __("Title Here", 'ahura')
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __("Title Typography", "ahura"),
                'selector' => '{{WRAPPER}} .introduction-box h2',
                'fields_options' =>
                [
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '38'
                        ]
                    ]
                ]
            ]
        );
        $this->add_control(
            'subtitle',
            [
            'label' => __('Subtitle', 'ahura'),
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => __("Subtitle Here", 'ahura')
        ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'sub_title_typography',
                'label' => __("Sub Title Typography", "ahura"),
                'selector' => '{{WRAPPER}} .introduction-box h3',
                'fields_options' =>
                [
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '24'
                        ]
                    ]
                ]
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => __('Image', 'ahura'),
                'type' => \Elementor\Controls_Manager::MEDIA
            ]
		);
        $this->add_responsive_control(
			'width',
			[
				'label' => __( 'Width', 'ahura' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'default' => [
					'unit' => '%',
				],
				'tablet_default' => [
					'unit' => '%',
				],
				'mobile_default' => [
					'unit' => '%',
				],
				'size_units' => [ '%', 'px', 'vw' ],
				'range' => [
					'%' => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .introduction-box-left' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'ahura' ),
				'types' => [ 'classic', 'gradient'],
                'fields_options' => 
				[
					'background' => [
						'default' => 'gradient'
					],
					'color' => [
						'default' => '#521d91'
					],
					'color_b' => [
						'default' => '#4a42ec'
                    ],
                    'gradient_angle' =>[
                        'default' => [
                            'unit' => 'deg',
                            'size' => 200,
                        ],
                    ]
                ],
				'selector' => '{{WRAPPER}} .introduction-box',
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'ahura' ),
				'selector' => '{{WRAPPER}} .introduction-box',
			]
		);
        $this->add_control(
            'title_color',
            [
                'label' => __('Title Color', 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
					'{{WRAPPER}} .introduction-box h2' => 'color: {{VALUE}}'
				]
            ]
		);
        $this->add_control(
            'sub_title_color',
            [
                'label' => __('Sub Title Color', 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
					'{{WRAPPER}} .introduction-box h3' => 'color: {{VALUE}}'
				]
            ]
		);
        $this->add_control(
            'url',
            [
                'label'     => __('Url', 'ahura'),
                'type'      => \Elementor\Controls_Manager::URL,
                'default'   => [
                    'url' => '#',
                ],
            ]
        );
        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>
        <a href="<?php echo $settings['url']['url'];?>" class="introduction-box">
            <div class="introduction-box-right">
                <h2><?php echo $settings['title'];?></h2>
                <h3><?php echo $settings['subtitle'];?></h3>
            </div>
            <div class="introduction-box-left">
                <img src="<?php echo $settings['image']['url'];?>">
            </div>
        </a>
        <?php
    }
}
