<?php

// Block direct access to the main plugin file.
defined('ABSPATH') or die('No script kiddies please!');


class Elementor_Post_list3 extends \Elementor\Widget_Base
{

	public function get_name()
	{
		return 'postlist3';
	}

	public function get_title()
	{
		return __('Post List 3', 'ahura');
	}

	public function get_icon()
	{
		return 'fa fa-list';
	}

	public function get_categories()
	{
		return ['ahuraelements'];
	}

	protected function _register_controls()
	{
		$this->start_controls_section(
			'content_section',
			[
				'label' => __('Content', 'ahura'),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$categories = get_categories();
		$cats       = array();
		foreach ($categories as $category) {
			$cats[$category->term_id] = $category->name;
		}
		$default = key($cats);
		$this->add_control(
			'catsid',
			[
				'label'    => __('Categories', 'ahura'),
				'type'     => \Elementor\Controls_Manager::SELECT2,
				'options'  => $cats,
				'label_block' => true,
				'multiple' => true,
				'default' => $default
			]
		);

		$this->add_control(
			'direction',
			[
				'label' => __('Alignment', 'ahura'),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'right' => [
						'title' => __('Right', 'ahura'),
						'icon' => 'fa fa-align-right',
					],
					'left' => [
						'title' => __('Left', 'ahura'),
						'icon' => 'fa fa-align-left',
					]
				],
				'default' => 'right',
				'toggle' => true,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __("Title Typography","ahura"),
				'selector' => '{{WRAPPER}} .post-list-3-title',
				'fields_options' =>
				[
					'font_size' => [
						'default' => [
							'unit' => 'px',
							'size' => '19'
						]
					]
				]
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' => __("Title Color", 'ahura'),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#35495C',
				'selectors' => [
					'{{WRAPPER}} .post-list-3-title' => 'color: {{VALUE}}'
				]
			]
		);
		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings_for_display();
		$catidd   = $settings['catsid'];
		$first_cat_id = $catidd && is_array($catidd) ? $catidd[0] : $catidd;
		$postbox1 = new WP_Query(array(
			'posts_per_page' => 1,
			'cat'            => $catidd,
		));
		if ($postbox1->have_posts()) : ?>
			<?php while ($postbox1->have_posts()) : $postbox1->the_post(); ?>
				<div class="post-list-3 post-list-3-<?php echo $settings['direction']; ?>">
					<div class="post-list-3-thumbnail">
						<a href="<?php the_permalink(); ?>">
							<?php the_post_thumbnail('stthumb'); ?>
						</a>
						<a href="<?php the_permalink(); ?>" class="post-list-3-title">
							<?php the_title(); ?>
						</a>
					</div>
				</div>
			<?php endwhile; ?>
			<?php wp_reset_postdata(); ?>
		<?php else : ?>
			<div class="mw_element_error">
				<?php echo __('Nothing found. Edit the page with Mentor and select a category for this section.', 'ahura'); ?>
			</div>
		<?php endif; ?>
		<div class="clear"></div>
<?php
	}
}
