<?php

// Block direct access to the main plugin file.
defined('ABSPATH') or die('No script kiddies please!');


class Elementor_Post_list4 extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'postlist4';
    }

    public function get_title()
    {
        return __('Post List 4', 'ahura');
    }

    public function get_icon()
    {
        return 'fa fa-list';
    }

    public function get_categories()
    {
        return ['ahuraelements'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'ahura'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $categories = get_categories();
        $cats       = array();
        foreach ($categories as $category) {
            $cats[$category->term_id] = $category->name;
        }
        $default = key($cats);
        $this->add_control(
            'catsid',
            [
                'label'    => __('Categories', 'ahura'),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'options'  => $cats,
                'label_block' => true,
                'multiple' => true,
                'default' => $default
            ]
        );
        $this->add_control(
            'postcount',
            [
                'label'      => __('Number of posts', 'ahura'),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'default'    => 3
            ]
        );
        $this->add_control(
            'title',
            [
                'label'      => __('Title', 'ahura'),
                'type'       => \Elementor\Controls_Manager::TEXT,
                'default'    => __('Title Here', 'ahura'),
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __("Title Typography", "ahura"),
                'selector' => '{{WRAPPER}} .post-list-4-title',
                'fields_options' =>
                [
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '32'
                        ]
                    ]
                ]
            ]
        );
        $this->add_control(
            'title_color',
            [
                'label' => __("Title Color", 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#35495C',
                'selectors' => [
                    '{{WRAPPER}} .post-list-3-title' => 'color: {{VALUE}}'
                ]
            ]
        );
        $this->add_control(
            'description',
            [
                'label'      => __('Title', 'ahura'),
                'type'       => \Elementor\Controls_Manager::TEXTAREA,
                'default'    => __('Description Here', 'ahura'),
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'description_typography',
                'label' => __("Description Typography", "ahura"),
                'selector' => '{{WRAPPER}} .post-list-4-description',
                'fields_options' =>
                [
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '20'
                        ]
                    ]
                ]
            ]
        );
        $this->add_control(
            'description_color',
            [
                'label' => __("Description Color", 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#35495C',
                'selectors' => [
                    '{{WRAPPER}} .post-list-3-title' => 'color: {{VALUE}}'
                ]
            ]
        );
        $this->add_control(
            'linktxet',
            [
                'label'      => __('Title', 'ahura'),
                'type'       => \Elementor\Controls_Manager::TEXT,
                'default'    => __('Title Here', 'ahura'),
            ]
        );
        $this->add_control(
            'linkurl',
            [
                'label'      => __('Url', 'ahura'),
                'type'       => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                ],
            ]
        );
        $this->add_control(
            'link_bg_color',
            [
                'label' => __("Link Background Color", 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#ffc33a',
                'selectors' => [
                    '{{WRAPPER}} .post-list-4-link' => 'background-color: {{VALUE}}'
                ]
            ]
        );
        $this->add_control(
            'link_color',
            [
                'label' => __("Link Color", 'ahura'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'default' => '#35495c',
                'selectors' => [
                    '{{WRAPPER}} .post-list-4-link' => 'color: {{VALUE}}'
                ]
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'link_typography',
                'label' => __("Link Typography", "ahura"),
                'selector' => '{{WRAPPER}} .post-list-4-link',
                'fields_options' =>
                [
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '16'
                        ]
                    ]
                ]
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'label' => __('Link shadow', 'ahura'),
                'name' => 'linktextshdow',
                'selector' => "{{WRAPPER}} .post-list-4-link"
            ]
        );
        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $catidd   = $settings['catsid'];
        $first_cat_id = $catidd && is_array($catidd) ? $catidd[0] : $catidd;
        $postbox1 = new WP_Query(array(
            'posts_per_page' => $settings['postcount'],
            'cat'            => $catidd,
        ));
        if ($postbox1->have_posts()) : ?>
            <div class="post-list-4">
                <div class="post-list-4-top-box">
                    <div class="post-list-top-box-right">
                        <div class="post-list-4-title">
                            <?php echo $settings['title']; ?>
                        </div>
                        <div class="post-list-4-description">
                            <?php echo $settings['description']; ?>
                        </div>
                    </div>
                    <div class="post-list-4-top-box-left">
                        <a href="<?php echo $settings['linkurl']['url']; ?>" class="post-list-4-link"><?php echo $settings['linktxet']; ?></a>
                    </div>
                </div>
                <div class="post-list-4-items">
                    <?php while ($postbox1->have_posts()) : $postbox1->the_post(); ?>
                        <a href="<?php the_permalink(); ?>" class="post-list-4-item">
                            <div class="post-list-4-thumbnail">
                                <?php the_post_thumbnail('sqthumb') ?>
                            </div>
                            <div class="post-list-4-post-title">
                                <h3><?php the_title(); ?></h3>
                            </div>
                        </a>
                    <?php endwhile; ?>
                </div>
            </div>
            <?php wp_reset_postdata(); ?>
        <?php else : ?>
            <div class="mw_element_error">
                <?php echo __('Nothing found. Edit the page with Mentor and select a category for this section.', 'ahura'); ?>
            </div>
        <?php endif; ?>
        <div class="clear"></div>
<?php
    }
}
