<?php

// Block direct access to the main plugin file.
defined('ABSPATH') or die('No script kiddies please!');


class Elementor_Suggestion_Posts extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'suggestion';
    }

    public function get_title()
    {
        return __('Suggestion Posts', 'ahura');
    }

    public function get_icon()
    {
        return 'fa fa-inbox';
    }

    public function get_categories()
    {
        return ['ahuraelements'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __('Content', 'ahura'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $categories = get_categories();
        $cats       = array();
        foreach ($categories as $category) {
            $cats[$category->term_id] = $category->name;
        }
        $default = key($cats);
        $this->add_control(
            'catsid',
            [
                'label'    => __('Categories', 'ahura'),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'options'  => $cats,
                'label_block' => true,
                'multiple' => false,
                'default' => $default
            ]
        );

        $this->add_control(
			'postcount',
			[
				'label'      => __( 'Number of posts', 'ahura' ),
				'type'       => \Elementor\Controls_Manager::NUMBER,
				'default'    => 6
			]
		);

        $this->add_control(
			'post_title_color',
			[
				'label'      => __( 'Title Color', 'ahura' ),
				'type'       => \Elementor\Controls_Manager::COLOR,
                'selectors' =>
				[
					'{{WRAPPER}} .suggestion-posts .suggestion-posts-item span' => 'color: {{VALUE}}'
				]
			]
		);

        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'post_title_typoghrapghy',
				'label' => __("Title Typography","ahura"),
				'selector' => '{{WRAPPER}} .suggestion-posts .suggestion-posts-item span',
			]
		);



        $this->end_controls_section();
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
?>

        <div class="suggestion-posts">
            <?php $the_query = new WP_Query(array(
                'posts_per_page' => $settings['postcount'],
                'cat' => $settings['catsid'],
            ));
            if ($the_query->have_posts()) :
                while ($the_query->have_posts()) : $the_query->the_post();
            ?>
                <a href="<?php the_permalink()?>" class="suggestion-posts-item">
                    <?php the_post_thumbnail('smthumb');?>
                    <span><?php the_title();?></span>
                </a>
            <?php
                endwhile;
            endif;
            ?>
        </div>

<?php
    }
}
